@@ -14,8 +14,7 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 package Devscripts::Packages;
 
@@ -87,7 +86,7 @@ sub PackagesToFiles (@)
     if ($pid) {   # parent
 	while (<DPKG>) {
 	    chomp;
-	    next if /^package diverts others to: /;
+	    next if /^package diverts others to: / or -d $_;
 	    $files{$_} = 1;
 	}
 	close DPKG or croak("dpkg -L failed: $!");
@@ -103,9 +102,9 @@ sub PackagesToFiles (@)
 
 
 # This basically runs a dpkg -S with a few bells and whistles
-# 
+#
 # input:  a list of files.
-# output: list of packages they belong to. 
+# output: list of packages they belong to.
 
 sub FilesToPackages (@)
 {
@@ -151,7 +150,7 @@ sub FilesToPackages (@)
     my ($curfile, $pkgfrom);
     undef $pkgfrom;
     $curfile = shift;
-    
+
     foreach (@dpkg_out) {
 	# We want to handle diversions nicely.
 	# Ignore local diversions
@@ -257,7 +256,7 @@ sub InstalledPackages ($)
     close PKG or croak("Problem reading grep pipe: $!");
 
     return \%matches;
-}    
+}
 
 1;
 
